@@ -43,6 +43,7 @@ from evergreen.task import Task
 from evergreen.task_annotations import TaskAnnotation
 from evergreen.task_reliability import TaskReliability
 from evergreen.tst import Tst
+from evergreen.users_for_role import UsersForRole
 from evergreen.util import evergreen_input_to_output, format_evergreen_date, iterate_by_time_window
 from evergreen.version import RecentVersions, Requester, Version
 
@@ -1069,14 +1070,44 @@ class EvergreenApi(object):
             payload["resource_id"] = resource_id
         self._call_api(url, method="DELETE", data=json.dumps(payload))
 
-    def get_users_for_role(self, role: str) -> List[str]:
+    def get_users_for_role(self, role: str) -> UsersForRole:
         """
         Get a list of users having an evergreen role.
 
         :param role: Role to fetch users for.
         """
         url = self._create_url(f"/roles/{role}/users")
-        return self._call_api(url, method="GET").json()
+        return UsersForRole(self._call_api(url, method="GET").json(), self)
+
+    def all_user_permissions_for_resource(
+        self, resource_id: str, resource_type: PermissionableResourceType
+    ) -> Dict[str, Dict[str, int]]:
+        """
+        Get all users with their permissions to the resource.
+
+        The returned dict has the following structure - 
+
+        .. code-block:: json
+
+            {
+              "username_1": {
+                 "project_tasks": 30,
+                 "project_patches": 10
+                },
+              "username_2": {
+                 "project_settings": 20,
+                 "project_patches": 10
+              }
+            }
+
+        :param resource_id: Id of the resource to get users for.
+        :param resource_type: Resource type of the resource.
+        :return: A dict containing user to permissions mappings.
+        """
+        url = self._create_url("/users/permissions")
+        return self._call_api(
+            url, data=json.dumps({"resource_id": resource_id, "resource_type": resource_type})
+        ).json()
 
     @classmethod
     def get_api(
